import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import SvgIcon from '../../../components/SvgIcon';
import { useDispatch } from 'react-redux';
import { showNotification } from '../../../store/notification.slice';

export default function SettingsTab({ knowledgeBase }) {
    const dispatch = useDispatch();
    // State for pagination
    const [currentPage, setCurrentPage] = useState(1);
    const usersPerPage = 10;

    // State for edit modal
    const [showEditModal, setShowEditModal] = useState(false);
    const [editUser, setEditUser] = useState(null);
    const [formErrors, setFormErrors] = useState({});

    // Mock data for users with permissions - convert to state so we can update it
    const [users, setUsers] = useState([
        {
            id: '1001',
            username: '张三',
            email: 'zhang@abc.com',
            permissionType: '只读',
            accessDuration: '一个月',
        },
        {
            id: '1002',
            username: '李四',
            email: 'li@abc.com',
            permissionType: '完全访问',
            accessDuration: '永久',
        },
        {
            id: '1003',
            username: '王五',
            email: 'wang@abc.com',
            permissionType: '只读',
            accessDuration: '三个月',
        },
        {
            id: '1004',
            username: '赵六',
            email: 'zhao@abc.com',
            permissionType: '完全访问',
            accessDuration: '六个月',
        },
        {
            id: '1005',
            username: '钱七',
            email: 'qian@abc.com',
            permissionType: '只读',
            accessDuration: '一周',
        },
        {
            id: '1006',
            username: '孙八',
            email: 'sun@abc.com',
            permissionType: '只读',
            accessDuration: '一个月',
        },
        {
            id: '1007',
            username: '周九',
            email: 'zhou@abc.com',
            permissionType: '完全访问',
            accessDuration: '永久',
        },
        {
            id: '1008',
            username: '吴十',
            email: 'wu@abc.com',
            permissionType: '只读',
            accessDuration: '三个月',
        },
        {
            id: '1009',
            username: '郑十一',
            email: 'zheng@abc.com',
            permissionType: '完全访问',
            accessDuration: '六个月',
        },
        {
            id: '1010',
            username: '冯十二',
            email: 'feng@abc.com',
            permissionType: '只读',
            accessDuration: '一周',
        },
        {
            id: '1011',
            username: '陈十三',
            email: 'chen@abc.com',
            permissionType: '只读',
            accessDuration: '一个月',
        },
        {
            id: '1012',
            username: '褚十四',
            email: 'chu@abc.com',
            permissionType: '完全访问',
            accessDuration: '永久',
        },
    ]);

    // Get current users for pagination
    const indexOfLastUser = currentPage * usersPerPage;
    const indexOfFirstUser = indexOfLastUser - usersPerPage;
    const currentUsers = users.slice(indexOfFirstUser, indexOfLastUser);
    const totalPages = Math.ceil(users.length / usersPerPage);

    // Handle form submission
    const handleSubmit = (e) => {
        e.preventDefault();
        // Here you would typically call an API to update the knowledge base settings
        console.log('Updating knowledge base settings');
    };

    // Handle knowledge base deletion
    const handleDelete = () => {
        // Here you would typically call an API to delete the knowledge base
        console.log('Deleting knowledge base:', knowledgeBase.id);
    };

    // Handle edit user permissions
    const handleEditUser = (user) => {
        setEditUser({ ...user });
        setFormErrors({});
        setShowEditModal(true);
    };

    // Handle input change in edit modal
    const handleEditInputChange = (e) => {
        const { name, value } = e.target;
        setEditUser((prev) => ({
            ...prev,
            [name]: value,
        }));

        // Clear error if exists
        if (formErrors[name]) {
            setFormErrors((prev) => ({
                ...prev,
                [name]: '',
            }));
        }
    };

    // Validate edit form
    const validateEditForm = () => {
        const errors = {};

        if (!editUser.permissionType) {
            errors.permissionType = '请选择权限类型';
        }

        if (!editUser.accessDuration) {
            errors.accessDuration = '请选择访问时长';
        }

        setFormErrors(errors);
        return Object.keys(errors).length === 0;
    };

    // Handle save user permissions
    const handleSaveUserPermissions = () => {
        // Validate form
        if (!validateEditForm()) {
            return;
        }

        // Here you would typically call an API to update the user permissions
        console.log('Updating user permissions:', editUser);

        // Update the users array with the edited user
        setUsers((prevUsers) => prevUsers.map((user) => (user.id === editUser.id ? { ...editUser } : user)));

        // Show success notification (in a real app)
        dispatch(showNotification({ message: '用户权限已更新', type: 'success' }));

        // Close modal
        setShowEditModal(false);
    };

    // Handle pagination
    const handlePageChange = (pageNumber) => {
        setCurrentPage(pageNumber);
    };

    // Handle delete user
    const handleDeleteUser = (userId) => {
        // Here you would typically call an API to delete the user
        console.log('Deleting user:', userId);

        // Update the users array by removing the deleted user
        setUsers((prevUsers) => prevUsers.filter((user) => user.id !== userId));

        // Show success notification (in a real app)
        dispatch(showNotification({ message: '用户已删除', type: 'success' }));
    };

    return (
        <>
            {/* Breadcrumb navigation */}
            <div className='d-flex align-items-center mb-4 mt-3'>
                <nav aria-label='breadcrumb'>
                    <ol className='breadcrumb mb-0'>
                        <li className='breadcrumb-item'>
                            <Link className='text-secondary text-decoration-none' to='/'>
                                知识库
                            </Link>
                        </li>
                        <li className='breadcrumb-item'>
                            <Link
                                className='text-secondary text-decoration-none'
                                to={`/knowledge-base/${knowledgeBase.id}`}
                            >
                                {knowledgeBase.title}
                            </Link>
                        </li>
                        <li className='breadcrumb-item active text-dark' aria-current='page'>
                            设置
                        </li>
                    </ol>
                </nav>
            </div>

            {/* Settings form */}
            <div className='card border-0 shadow-sm'>
                <div className='card-body'>
                    <h5 className='card-title mb-4'>知识库设置</h5>

                    <form onSubmit={handleSubmit}>
                        <div className='mb-3'>
                            <label htmlFor='knowledgeTitle' className='form-label'>
                                知识库名称
                            </label>
                            <input
                                type='text'
                                className='form-control'
                                id='knowledgeTitle'
                                defaultValue={knowledgeBase.title}
                            />
                        </div>

                        <div className='mb-3'>
                            <label htmlFor='knowledgeDescription' className='form-label'>
                                知识库描述
                            </label>
                            <textarea
                                className='form-control'
                                id='knowledgeDescription'
                                rows='3'
                                defaultValue={knowledgeBase.description}
                            ></textarea>
                        </div>

                        <div className='mb-3'>
                            <label className='form-label'>访问权限</label>
                            <div className='form-check'>
                                <input
                                    className='form-check-input'
                                    type='radio'
                                    name='accessPermission'
                                    id='accessPublic'
                                    defaultChecked
                                />
                                <label className='form-check-label' htmlFor='accessPublic'>
                                    公开 - 所有人可访问
                                </label>
                            </div>
                            <div className='form-check'>
                                <input
                                    className='form-check-input'
                                    type='radio'
                                    name='accessPermission'
                                    id='accessPrivate'
                                />
                                <label className='form-check-label' htmlFor='accessPrivate'>
                                    私有 - 仅创建者可访问
                                </label>
                            </div>
                        </div>

                        <div className='mb-3'>
                            <label className='form-label'>权限管理</label>
                            <div className='card'>
                                <div className='card-body p-0'>
                                    <table className='table mb-0'>
                                        <thead className='table-light'>
                                            <tr>
                                                <th scope='col'>ID</th>
                                                <th scope='col'>用户名</th>
                                                <th scope='col'>邮箱</th>
                                                <th scope='col'>权限类型</th>
                                                <th scope='col'>访问时长</th>
                                                <th scope='col'>操作</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            {currentUsers.map((user) => (
                                                <tr key={user.id}>
                                                    <td>#{user.id}</td>
                                                    <td>{user.username}</td>
                                                    <td>{user.email}</td>
                                                    <td>
                                                        <span
                                                            className={
                                                                user.permissionType === '完全访问'
                                                                    ? 'text-success'
                                                                    : 'text-warning'
                                                            }
                                                        >
                                                            {user.permissionType}
                                                        </span>
                                                    </td>
                                                    <td>{user.accessDuration}</td>
                                                    <td>
                                                        <div className='d-flex gap-2'>
                                                            <button
                                                                className='btn btn-sm text-primary'
                                                                title='编辑'
                                                                onClick={() => handleEditUser(user)}
                                                            >
                                                                <SvgIcon className='edit' width='16' height='16' />
                                                            </button>
                                                            <button
                                                                className='btn btn-sm text-danger'
                                                                title='删除'
                                                                onClick={() => handleDeleteUser(user.id)}
                                                            >
                                                                <SvgIcon className='trash' width='16' height='16' />
                                                            </button>
                                                        </div>
                                                    </td>
                                                </tr>
                                            ))}
                                        </tbody>
                                    </table>
                                </div>
                            </div>

                            {/* Pagination */}
                            {users.length > usersPerPage && (
                                <div className='d-flex justify-content-end mt-3'>
                                    <nav aria-label='Page navigation'>
                                        <ul className='pagination pagination-sm mb-0'>
                                            <li className={`page-item ${currentPage === 1 ? 'disabled' : ''}`}>
                                                <button
                                                    className='page-link'
                                                    onClick={() => handlePageChange(currentPage - 1)}
                                                    disabled={currentPage === 1}
                                                >
                                                    <span aria-hidden='true'>&laquo;</span>
                                                </button>
                                            </li>

                                            {Array.from({ length: totalPages }, (_, i) => i + 1).map((pageNumber) => (
                                                <li
                                                    key={pageNumber}
                                                    className={`page-item ${
                                                        currentPage === pageNumber ? 'active' : ''
                                                    }`}
                                                >
                                                    <button
                                                        className='page-link'
                                                        onClick={() => handlePageChange(pageNumber)}
                                                    >
                                                        {pageNumber}
                                                    </button>
                                                </li>
                                            ))}

                                            <li className={`page-item ${currentPage === totalPages ? 'disabled' : ''}`}>
                                                <button
                                                    className='page-link'
                                                    onClick={() => handlePageChange(currentPage + 1)}
                                                    disabled={currentPage === totalPages}
                                                >
                                                    <span aria-hidden='true'>&raquo;</span>
                                                </button>
                                            </li>
                                        </ul>
                                    </nav>
                                </div>
                            )}

                            <button type='button' className='btn btn-outline-dark mt-2'>
                                <SvgIcon className='plus' width='16' height='16' />
                                <span className='ms-1'>添加用户</span>
                            </button>
                        </div>

                        <div className='d-flex justify-content-end gap-2 mt-4'>
                            <button type='button' className='btn btn-outline-danger' onClick={handleDelete}>
                                删除知识库
                            </button>
                            <button type='submit' className='btn btn-dark'>
                                保存设置
                            </button>
                        </div>
                    </form>
                </div>
            </div>

            {/* Edit User Permissions Modal */}
            {showEditModal && (
                <div
                    className='modal-backdrop'
                    style={{
                        position: 'fixed',
                        top: 0,
                        left: 0,
                        right: 0,
                        bottom: 0,
                        backgroundColor: 'rgba(0, 0, 0, 0.5)',
                        display: 'flex',
                        alignItems: 'center',
                        justifyContent: 'center',
                        zIndex: 1050,
                    }}
                >
                    <div
                        className='modal-content bg-white rounded shadow'
                        style={{
                            width: '500px',
                            maxWidth: '90%',
                            padding: '20px',
                        }}
                    >
                        <div className='modal-header d-flex justify-content-between align-items-center mb-3'>
                            <h5 className='modal-title m-0'>编辑用户权限</h5>
                            <button
                                type='button'
                                className='btn-close'
                                onClick={() => setShowEditModal(false)}
                                aria-label='Close'
                            ></button>
                        </div>
                        <div className='modal-body'>
                            <div className='mb-3'>
                                <label className='form-label'>用户信息</label>
                                <div className='card bg-light'>
                                    <div className='card-body'>
                                        <div className='d-flex justify-content-between mb-2'>
                                            <span className='text-muted'>ID:</span>
                                            <span>#{editUser?.id}</span>
                                        </div>
                                        <div className='d-flex justify-content-between mb-2'>
                                            <span className='text-muted'>用户名:</span>
                                            <span>{editUser?.username}</span>
                                        </div>
                                        <div className='d-flex justify-content-between'>
                                            <span className='text-muted'>邮箱:</span>
                                            <span>{editUser?.email}</span>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div className='mb-4'>
                                <label className='form-label d-flex align-items-center'>
                                    <SvgIcon className='key me-2' width='16' height='16' />
                                    权限类型 <span className='text-danger'>*</span>
                                </label>
                                <div className='d-flex gap-2'>
                                    <div
                                        className={`p-3 rounded border bg-warning-subtle ${
                                            editUser?.permissionType === '只读'
                                                ? 'border-warning'
                                                : 'border-warning-subtle opacity-50'
                                        }`}
                                        style={{ flex: 1, cursor: 'pointer' }}
                                        onClick={() =>
                                            handleEditInputChange({ target: { name: 'permissionType', value: '只读' } })
                                        }
                                    >
                                        <div className='text-center text-warning fw-bold mb-1'>只读</div>
                                        <div className='text-center text-muted small'>仅查看数据集内容</div>
                                    </div>
                                    <div
                                        className={`p-3 rounded border bg-success-subtle ${
                                            editUser?.permissionType === '完全访问'
                                                ? 'border-success'
                                                : 'border-success-subtle opacity-50'
                                        }`}
                                        style={{ flex: 1, cursor: 'pointer' }}
                                        onClick={() =>
                                            handleEditInputChange({
                                                target: { name: 'permissionType', value: '完全访问' },
                                            })
                                        }
                                    >
                                        <div className='text-center text-success fw-bold mb-1'>完全访问</div>
                                        <div className='text-center text-muted small'>查看、编辑和管理数据</div>
                                    </div>
                                </div>
                                {formErrors.permissionType && (
                                    <div className='text-danger small mt-1'>{formErrors.permissionType}</div>
                                )}
                            </div>

                            <div className='mb-3'>
                                <label className='form-label d-flex align-items-center'>
                                    <SvgIcon className='clock me-2' width='16' height='16' />
                                    访问时长 <span className='text-danger'>*</span>
                                </label>
                                <select
                                    className={`form-select ${formErrors.accessDuration ? 'is-invalid' : ''}`}
                                    name='accessDuration'
                                    value={editUser?.accessDuration || ''}
                                    onChange={handleEditInputChange}
                                    required
                                >
                                    <option value=''>请选择访问时长</option>
                                    <option value='一周'>一周</option>
                                    <option value='一个月'>一个月</option>
                                    <option value='三个月'>三个月</option>
                                    <option value='六个月'>六个月</option>
                                    <option value='永久'>永久</option>
                                </select>
                                {formErrors.accessDuration && (
                                    <div className='invalid-feedback'>{formErrors.accessDuration}</div>
                                )}
                            </div>
                        </div>
                        <div className='modal-footer d-flex justify-content-end gap-2'>
                            <button
                                type='button'
                                className='btn btn-outline-secondary'
                                onClick={() => setShowEditModal(false)}
                            >
                                取消
                            </button>
                            <button type='button' className='btn btn-dark' onClick={handleSaveUserPermissions}>
                                保存
                            </button>
                        </div>
                    </div>
                </div>
            )}
        </>
    );
}
